function ED = check_array_element (ED)

% Compute missing fields of array element descriptor.
%
% Array element's gain pattern parameters G0 and n for the 
% generic approximative pattern, in the elements principal axis system
%
%   G = G0*[cos(th/2)]^n
%
% At input, ED must have fields
%
%   .phi            azimuth angle (radians), measured c-clockw from x-ax.
%   .th             polar angle (radians)
%   .gain           (multiplicative power gain)
%   .width          (half power beam width, radians)
%
% One or the other, but not both, of the last two fields must be empty.  
%

% 23-Oct-2005 Jm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n = [];
if ~isfield (ED,'width') | isempty (ED.width) 
    if ~isfield (ED,'gain') | isempty (ED.gain)
        error ('arraygain: Either element gain or beamwith must be specified');
    else
        n = 2*ED.gain - 2;
        ED.width = 4 * acos( (0.5)^(1/n) );
    end
end
if ~isfield (ED,'gain') | isempty (ED.gain)
    if ~isfield (ED,'width') | isempty (ED.width)
        error ('arraygain: Either element gain or beamwith must be specified');
    else
        n = log10 (0.5) / log10 (cos((ED.width/2)/2));
        ED.gain = (n+2)/2;
    end
end
if isempty(n)
    ED.n = log10 (0.5) / log10 (cos((ED.width/2)/2));
%    error ('arraygain: Must not specify both element gain and element width')
else
    ED.n = n;
end

%end check_element
