function plot_directivity

% PLOT_DIRECTIVITY
%
% Plot the directivity of a phased array.
%
%   See also powerint.m, plot_maxgain.m.

% 3-Nov-2005
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

set(0,'defaultaxesfontsize',14);
d2r = pi/180;
r2d = 180/pi;

c = 1;
AD.Mx = 50*c;
AD.My = 20*c;
AD.Dx = 1.5/c;
AD.Dy = 1.5/c;

ED.th    = 00*d2r;
ED.phi   = 00*d2r;
ED.gain  = 10*log10 (10.0);

th1 = 0;
th2 = 70*d2r;
th = linspace (th1,th2, 500);
N = length(th);

D = zeros (1,N);
P = zeros (1,N);
for k = 1:length(th)
    [P(k),D(k)] = powerint (AD, ED, ED.phi, th(k));
end


getfigure (mfilename, [ 1 1 6 4], 500);

h = plot ( th*r2d, 10*log10(D), '-.' );
    set (h, 'linewidth',1.5);
    xlabel ('Polar angle (\circ)');
    ylabel ('Directivity (dBi)');
    set (gca,'layer','top');
    set (gca,'tickdir','out');
    set (gca,'ticklength',[0.02 0.025]);
    
    legend({'Ideal','\theta_E=40\circ', 'theta_E=0\circ'};