function [G,G0] = simplegain ( phi, th, ED)

% G = SIMPLEGAIN (PHI, TH, ED)
%
% Normalized gain in direction PHI (azimuth, radians) and TH (polar angle)
% of an antenna element described by the element descriptor ED.
%
% This implementation requires the following fields in ED.
%
%   .phi        % element azimuth
%   .th         % element polar angle
%   .gain       % element power gain, as multiplicative factor
%   .width      % element halfpower beamwidth
%
% TH can be a row vector, PHI must be scalar.
%
% 23-Oct-2005 Jm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin ~= 3
    error ('Bad number of parameters')
end

G0    = ED.gain;
nE    = 2*G0-2;
Ephi  = ED.phi;
Eth   = ED.th;

[n,m] = size(th);
if n > 1
    error ('TH must be a row vector');
end

% Rotate the element's pattern to the array coordinate system.

% The Element's direction vector coordinates in the array system are

Ue = [sin(Eth)*cos(Ephi), sin(Eth)*sin(Ephi), cos(Eth)];

%  Matrix rr, where a column gives the direction vector r for a single th.

rr = [sin(th)*cos(phi); sin(th)*sin(phi); cos(th)];

% An element's normalized gain as function of theta, as a row vector

G = (0.5 * (1 + Ue*rr)) .^ (nE/2);

%end simplegain



