function sitegeom1

% SITEGEOM1
%
% Pointing information at a given site, for Tromso vertical, field
% alligned and CP2 pointing schemes. Input must be hardcoded to the file.
%
% 23-Oct-2005 Jm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% INPUT

% (1) Define ONE site name and location

if 0
    XName = 'KEVO';
    XLat = 69.75;
    XLon = 27.0;
    XAlt = 0.1;
elseif 0
    XName = 'KILPISJARVI';
    XLat = 69.07;
    XLon = 20.79;
    XAlt = 0.5;
elseif 0
    XName = 'PORJUS';
    XLat = 67.05;
    XLon = 19.58;
    XAlt = 0;
elseif 0
    XName = 'PURNUVAARA';
    XLat = 69.35;
    XLon = 27.20;
    XAlt = 0;
elseif 0
    XName = 'SODANKYLA';
    XLat = 67.363683;
    XLon = 26.627081;
    XAlt = 0.1973;
elseif 1
    XName = 'KIRUNA';
    XLat = 67.860658;     
    XLon = 20.435222;     
    XAlt = 0.4179;        
elseif 0
    XName = 'KOUTOKEINO';
    XLat = 69.00;     
    XLon = 23.05;
    XAlt = 0;        
elseif 0
    XName = 'ABISKO';
    XLat = 68.36;     
    XLon = 18.80;     
    XAlt = 0;        
end

Hmin = 0;
Hmax = 300;
H = 1:2:Hmax;

% (2) Define common volume altitude grid


% (3) If all data is in the northern sector, set the flag North,
%     then azimuth range will be from -180 to +180.

North = 0;

%======================================================================
% NORMALLY DO NOT TOUCH ANYTHING BELOW THIS LINE
%======================================================================

Desk = 'Tromso vertical (-), field-aligned 184.9, 77.4 (--), and CP2 (.)'

set(0,'defaultaxesfontsize',12);
d2r = pi/180;
r2d = 180/pi;

% Initilize EISCAT geom package

geom ('xsite',XLat,XLon,XAlt);
changersite ('T');              

% Call EISCAT geom routines to find the pointing values at X site.

for k = 1:length(H)
    G1 = pointrrange (180.0, 90.0, H(k));
    G2 = pointrheight (184.9, 77.4, H(k));

    Range(k,1)  = G1.rESR;
    El(k,1)     = G1.elESR;
    Az(k,1)     = G1.azESR;
    Gamma(k,1)  = G1.gammaESR;

    Range(k,2)  = G2.rESR;
    El(k,2)     = G2.elESR;
    Az(k,2)     = G2.azESR;
    Gamma(k,2)  = G2.gammaESR;
end

% CP2 positions

CP2_H = 292*ones(1,4);
G(1) = pointrheight (180.00, 90.00, CP2_H(1));
G(2) = pointgeographic (68.40, 20.00, CP2_H(2));
G(3) = pointgeographic (68.64, 21.92, CP2_H(3));
G(4) = pointrheight (184.9, 77.4, CP2_H(4));

for k = 1:4
    CP2_R(k)  = G(k).rESR;
    CP2_E(k)  = G(k).elESR;
    CP2_A(k)  = G(k).azESR;
    CP2_G(k)  = G(k).gammaESR;
end

%==========================================================
%                   GRAPHS
%==========================================================

getfigure ('Pointing geometry',[0.25 2.5 8 5], 700);
LS2 = '--';
MC = [0 0 0];

% Header

    h = subplot ('position', [0.1300    0.88    0.7750    0.10]);
        hdr{1} = sprintf('%s Lat=%1.2f Lon=%1.2f Hgt=%1.2f', ...
                        XName, XLat, XLon, XAlt);
        hdr{2} =  Desk;
    figureheader (h, hdr);

% Elevation
    
    subplot ('position', [0.1300    0.53    0.3347    0.30]);
    h = plot (CP2_H, CP2_E,'ko'); setmarker(h,MC); hold on; 
    h = plot (H,El); hold off; 
        set (h, 'linewidth', 1.5);
        set (h, 'color', [0 0 1]);
        if length(h) > 1
             set (h(2), 'color', [1 0 0]);
             set (h(2), 'linestyle', LS2); 
        end
        ylabel ('Elevation (\circ)')
        xlabel ('CV altitude (km)')
        ylim = get(gca,'ylim');
        set (gca,'ylim',[max([0,ylim(1)]), ylim(2)]);
        set (gca,'xlim',[Hmin,Hmax]);
        setax

% Azimuth
    
    % Limits requires special handling when all data is near 360.

    if North
        K = find (Az > 180); 
        Az(K) = Az(K) - 360;
        K = find (CP2_A > 180); 
        CP2_A(K) = CP2_A(K) - 360;
    end

    subplot ('position', [0.5708    0.53    0.3342    0.30]);
    h = plot (CP2_H, CP2_A,'ko'); setmarker(h,MC); hold on;
    h = plot (H,Az); hold off;
        set (h, 'linewidth', 1.5);
        set (h, 'color', [0 0 1]);
        if length(h) > 1
             set (h(2), 'color', [1 0 0]);
             set (h(2), 'linestyle', LS2); 
        end
        ylabel('Azimuth (\circ)')
        xlabel ('CV altitude (km)')
        set (gca,'xlim',[Hmin,Hmax]);        


%        D = max (1, [0.1*(az2-az1)]);
%        set(gca,'ylim', [az1-D, az2+D]);
        setax

% Range
    
    subplot('position', [0.1300    0.1100    0.3347    0.30])
    h = plot (CP2_H, CP2_R,'ko'); setmarker(h,MC); hold on;
    h = plot (H,Range); hold off
        set (h, 'linewidth', 1.5);
        set (h, 'color', [0 0 1]);
        if length(h) > 1
             set (h(2), 'color', [1 0 0]);
             set (h(2), 'linestyle', LS2); 
        end
        ylabel('Range (km)')
        xlabel ('CV altitude (km)');
        set (gca,'xlim',[Hmin,Hmax]);
%        R1 = min(min(Range));
%        R2 = max(max(Range));
%        D = max ([1, 0.1*(R2-R1)]);
%        set(gca,'ylim', [R1-D, R2+D]);
        setax

% Beam intersection angle
    
    subplot('position', [0.5708    0.1100    0.3342    0.30])
    h=plot (CP2_H, CP2_G,'ko'); setmarker(h,MC); hold on;
    h = plot (H,Gamma); hold off;
        set (h, 'linewidth', 1.5);
        set (h, 'color', [0 0 1]);
        if length(h) > 1
             set (h(2), 'color', [1 0 0]);
             set (h(2), 'linestyle', LS2); 
        end
        ylabel('Intersection angle (\circ)')
        set (gca,'xlim',[Hmin,Hmax]);
        xlabel ('CV altitude (km)')
        setax

end %main


%==========================================================
%                   SUBFUNCTIONS
%==========================================================

function setmarker(h,color)
%-------------------------------------------------
%
%
%-------------------------------------------------
    set(h,'markerfacecolor',color);
    set(h,'markeredgecolor',color);
    set(h,'markersize',4);
end %setmarker


function setax
%-------------
    set (gca,'layer','top');
    set (gca,'tickdir','out');
    set (gca,'ticklength',[0.020 0.035]);
end



